@@ -53,6 +53,7 @@ class TestProviderDataModels(base.TestCase):
             l7policy_id=self.l7policy_id,
             l7rule_id=self.l7rule_id,
             type='COOKIE',
+            project_id=self.project_id,
             value='chocolate')
 
         self.ref_l7policy = data_models.L7Policy(
@@ -66,7 +67,9 @@ class TestProviderDataModels(base.TestCase):
             redirect_pool_id=self.pool_id,
             redirect_url='/test',
             rules=[self.ref_l7rule],
-            redirect_prefix='http://example.com')
+            project_id=self.project_id,
+            redirect_prefix='http://example.com',
+            redirect_http_code=301)
 
         self.ref_listener = data_models.Listener(
             admin_state_up=True,
@@ -81,6 +84,7 @@ class TestProviderDataModels(base.TestCase):
             listener_id=self.listener_id,
             loadbalancer_id=self.loadbalancer_id,
             name='super_listener',
+            project_id=self.project_id,
             protocol='avian',
             protocol_port=42,
             sni_container_data=['sni_cert_data_1', 'sni_cert_data_2'],
@@ -89,7 +93,12 @@ class TestProviderDataModels(base.TestCase):
             timeout_client_data=3,
             timeout_member_connect=4,
             timeout_member_data=5,
-            timeout_tcp_inspect=6)
+            timeout_tcp_inspect=6,
+            client_authentication=None,
+            client_ca_tls_container_data=None,
+            client_ca_tls_container_ref=None,
+            client_crl_container_data=None,
+            client_crl_container_ref=None)
 
         self.ref_lb = data_models.LoadBalancer(
             admin_state_up=False,
@@ -120,6 +129,7 @@ class TestProviderDataModels(base.TestCase):
             monitor_port=8888,
             name='member',
             pool_id=self.pool_id,
+            project_id=self.project_id,
             protocol_port=80,
             subnet_id=self.mem_subnet_id,
             weight=1,
@@ -135,9 +145,12 @@ class TestProviderDataModels(base.TestCase):
             max_retries_down=3,
             name='member',
             pool_id=self.pool_id,
+            project_id=self.project_id,
             timeout=4,
             type='HTTP',
-            url_path='/test')
+            url_path='/test',
+            http_version=1.1,
+            domain_name='testdomainname.com')
 
         self.ref_pool = data_models.Pool(
             admin_state_up=True,
@@ -148,6 +161,7 @@ class TestProviderDataModels(base.TestCase):
             members=[self.ref_member],
             name='pool',
             pool_id=self.pool_id,
+            project_id=self.project_id,
             listener_id=self.listener_id,
             protocol='avian',
             session_persistence=self.session_persistence)
@@ -159,6 +173,7 @@ class TestProviderDataModels(base.TestCase):
                                 'l7policy_id': self.l7policy_id,
                                 'l7rule_id': self.l7rule_id,
                                 'type': 'COOKIE',
+                                'project_id': self.project_id,
                                 'value': 'chocolate'}
 
         self.ref_l7policy_dict = {'action': 'REJECT',
@@ -168,10 +183,12 @@ class TestProviderDataModels(base.TestCase):
                                   'listener_id': self.listener_id,
                                   'name': 'l7policy',
                                   'position': 1,
+                                  'project_id': self.project_id,
                                   'redirect_pool_id': self.pool_id,
                                   'redirect_url': '/test',
                                   'rules': [self.ref_l7rule_dict],
-                                  'redirect_prefix': 'http://example.com'}
+                                  'redirect_prefix': 'http://example.com',
+                                  'redirect_http_code': 301}
 
         self.ref_lb_dict = {'project_id': self.project_id,
                             'flavor': {'cake': 'chocolate'},
@@ -198,6 +215,7 @@ class TestProviderDataModels(base.TestCase):
             'l7policies': [self.ref_l7policy_dict],
             'loadbalancer_id': self.loadbalancer_id,
             'name': 'super_listener',
+            'project_id': self.project_id,
             'protocol': 'avian',
             'protocol_port': 42,
             'sni_container_data': ['sni_cert_data_1', 'sni_cert_data_2'],
@@ -206,7 +224,12 @@ class TestProviderDataModels(base.TestCase):
             'timeout_client_data': 3,
             'timeout_member_connect': 4,
             'timeout_member_data': 5,
-            'timeout_tcp_inspect': 6}
+            'timeout_tcp_inspect': 6,
+            'client_authentication': None,
+            'client_ca_tls_container_data': None,
+            'client_ca_tls_container_ref': None,
+            'client_crl_container_data': None,
+            'client_crl_container_ref': None, }
 
         self.ref_lb_dict_with_listener = {
             'admin_state_up': False,
@@ -237,6 +260,7 @@ class TestProviderDataModels(base.TestCase):
             'monitor_port': 8888,
             'name': 'member',
             'pool_id': self.pool_id,
+            'project_id': self.project_id,
             'protocol_port': 80,
             'subnet_id': self.mem_subnet_id,
             'weight': 1,
@@ -252,9 +276,12 @@ class TestProviderDataModels(base.TestCase):
             'max_retries_down': 3,
             'name': 'member',
             'pool_id': self.pool_id,
+            'project_id': self.project_id,
             'timeout': 4,
             'type': 'HTTP',
-            'url_path': '/test'}
+            'url_path': '/test',
+            'http_version': 1.1,
+            'domain_name': 'testdomainname.com'}
 
         self.ref_pool_dict = {
             'admin_state_up': True,
@@ -265,6 +292,7 @@ class TestProviderDataModels(base.TestCase):
             'members': [self.ref_member_dict],
             'name': 'pool',
             'pool_id': self.pool_id,
+            'project_id': self.project_id,
             'listener_id': self.listener_id,
             'protocol': 'avian',
             'session_persistence': self.session_persistence}
@@ -346,6 +374,7 @@ class TestProviderDataModels(base.TestCase):
         new_ref_lib_dict = deepcopy(self.ref_lb_dict)
         new_ref_lib_dict['pools'] = None
         new_ref_lib_dict['listeners'] = None
+        new_ref_lib_dict['additional_vips'] = None
 
         self.assertEqual(new_ref_lib_dict, ref_lb_converted_to_dict)
 
@@ -393,6 +422,7 @@ class TestProviderDataModels(base.TestCase):
         ref_lb_dict_with_listener = deepcopy(self.ref_lb_dict_with_listener)
         ref_lb_dict_with_listener['pools'] = None
         ref_lb_dict_with_listener['name'] = None
+        ref_lb_dict_with_listener['additional_vips'] = None
 
         ref_lb_converted_to_dict = ref_lb.to_dict(recurse=True,
                                                   render_unsets=True)
